@@ -1,9 +1,15 @@
 import copy
 import json
 import os
+import types
 from os.path import join, splitext, expanduser
 
-from .util import six, yaml
+from .env import Environment
+from .exceptions import UnknownFileType, UnpicklableConfigMember
+from .runners import Local
+from .terminals import WINDOWS
+from .util import debug, six, yaml
+
 
 if six.PY3:
     try:
@@ -26,13 +32,6 @@ else:
         return vars(imp.load_source("mod", path))
 
 
-from .env import Environment
-from .exceptions import UnknownFileType
-from .runners import Local
-from .terminals import WINDOWS
-from .util import debug
-
-
 class DataProxy(object):
     """
     Helper class implementing nested dict+attr access for `.Config`.
@@ -470,36 +469,41 @@ class Config(DataProxy):
             # default" that could go here. Alternately, make _more_ of these
             # default to None?
             "run": {
-                "warn": False,
-                "hide": None,
-                "shell": shell,
-                "pty": False,
-                "fallback": True,
-                "env": {},
-                "replace_env": False,
+                "asynchronous": False,
+                "disown": False,
+                "dry": False,
                 "echo": False,
-                "encoding": None,
-                "out_stream": None,
-                "err_stream": None,
-                "in_stream": None,
-                "watchers": [],
                 "echo_stdin": None,
+                "encoding": None,
+                "env": {},
+                "err_stream": None,
+                "fallback": True,
+                "hide": None,
+                "in_stream": None,
+                "out_stream": None,
+                "pty": False,
+                "replace_env": False,
+                "shell": shell,
+                "warn": False,
+                "watchers": [],
             },
             # This doesn't live inside the 'run' tree; otherwise it'd make it
             # somewhat harder to extend/override in Fabric 2 which has a split
             # local/remote runner situation.
             "runners": {"local": Local},
             "sudo": {
-                "prompt": "[sudo] password: ",
                 "password": None,
+                "prompt": "[sudo] password: ",
                 "user": None,
             },
             "tasks": {
-                "dedupe": True,
                 "auto_dash_names": True,
                 "collection_name": "tasks",
+                "dedupe": True,
+                "executor_class": None,
                 "search_root": None,
             },
+            "timeouts": {"command": None},
         }
 
     def __init__(
@@ -874,7 +878,7 @@ class Config(DataProxy):
                 try:
                     type_ = splitext(filepath)[1].lstrip(".")
                     loader = getattr(self, "_load_{}".format(type_))
-                except AttributeError as e:
+                except AttributeError:
                     msg = "Config files of type {!r} (from file {!r}) are not supported! Please use one of: {!r}"  # noqa
                     raise UnknownFileType(
                         msg.format(type_, filepath, self._file_suffixes)
@@ -887,8 +891,7 @@ class Config(DataProxy):
                 break
             # Typically means 'no such file', so just note & skip past.
             except IOError as e:
-                # TODO: is there a better / x-platform way to detect this?
-                if "No such file" in e.strerror:
+                if e.errno == 2:
                     err = "Didn't see any {}, skipping."
                     debug(err.format(filepath))
                 else:
@@ -914,8 +917,18 @@ class Config(DataProxy):
     def _load_py(self, path):
         data = {}
         for key, value in six.iteritems(load_source("mod", path)):
+            # Strip special members, as these are always going to be builtins
+            # and other special things a user will not want in their config.
             if key.startswith("__"):
                 continue
+            # Raise exceptions on module values; they are unpicklable.
+            # TODO: suck it up and reimplement copy() without pickling? Then
+            # again, a user trying to stuff a module into their config is
+            # probably doing something better done in runtime/library level
+            # code and not in a "config file"...right?
+            if isinstance(value, types.ModuleType):
+                err = "'{}' is a module, which can't be used as a config value. (Are you perhaps giving a tasks file instead of a config file by mistake?)"  # noqa
+                raise UnpicklableConfigMember(err.format(key))
             data[key] = value
         return data
 
